require 'netspace/subnet'

module NetSpace

  #
  # Load a file containing CIDR subnet definitions, one per
  # line.  The result will be an array of Subnet objects.

  def self.load(file)
    NetSpace::parse(File.read(file))
  end

  #
  # Parse a string containing CIDR subnet definitions, one
  # per line.  The result will be an array of Subnet objects.
  #
  
  def self.parse(string)
    nets = string.split(/\n/).map do |line|
      begin
        line.strip!
        line =~ /^([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)\/([0-9]+)$/
        Subnet.new($1, $2.to_i)
      rescue
        nil
      end
    end
    return nets - [nil]
  end

  #
  # Utility for converting a string IP (e.g. "127.0.0.1") to
  # it's 32-bit integer equivalent (e.g., 2130706433).
  #

  def self.ip2num(ip)
    return ip.split(/\./).map {|i| i.to_i}.pack("C*").unpack("N")[0]
  end
  
  #
  # Utility for converting a 32-bit integer IP (e.g. 2130706433)
  # to it's string equivalent (e.g., "127.0.0.1").
  #

  def self.num2ip(num)
    return [num].pack("N").unpack("C*").join(".")
  end
end
