module NetSpace

  #
  # Class representing an IP subnet.  At its core, it's a base
  # IP and a netmask, both converted to 32-bit integers for fast
  # comparisons.
  #
  
  class Subnet
    attr_accessor :ip, :ip32, :bits, :mask, :mask32
    
    def initialize(ip, bits)
      @ip     = ip
      @bits   = bits
      @ip32   = NetSpace::ip2num(ip)
      @mask32 = ~(2 ** (32 - @bits) - 1)
      @mask   = NetSpace::num2ip(@mask32)
    end

    #
    # Test if indicated IP address resides within the boundaries
    # of the subnet.
    # 

    def in?(ip)
      return NetSpace::ip2num(ip) & @mask32 == @ip32
    end

    #
    # Return a list of all IPs (as strings) that are legitimately
    # members of the subnet.
    #
    
    def ips
      is = []
      ip = @ip32
      while ip & @mask32 == @ip32
        is << NetSpace::num2ip(ip)
        ip += 1
      end
      return is
    end
  end
end
